Module backend

Module backend 

This module exposes a backend trait for Subxt which allows us to get and set the necessary information (probably from a JSON-RPC API, but that’s up to the implementation).

Modules

utils
Backend utils.

Structs

ArchiveBackend
The archive backend.
BlockRef
An opaque struct which, while alive, indicates that some references to a block still exist. This gives the backend the opportunity to keep the corresponding block details around for a while if it likes and is able to. No guarantees can be made about how long the corresponding details might be available for, but if no references to a block exist, then the backend is free to discard any details for it.
ChainHeadBackend
The chainHead backend.
ChainHeadBackendBuilder
Configure and build an ChainHeadBackend.
ChainHeadBackendDriver
Driver for the ChainHeadBackend. This must be polled in order for the backend to make progress.
CombinedBackend
A combined backend. This selects which RPC calls to use based on the rpc_methods available from the given RPC client we’re given.
CombinedBackendBuilder
A builder to configure and build a CombinedBackend.
CombinedBackendDriver
Driver for the CombinedBackend. This needs to be polled to ensure that the CombinedBackend can make progress. It does not need polling if CombinedBackendDriver::needs_polling returns false.
LegacyBackend
The legacy backend.
LegacyBackendBuilder
Configure and build an LegacyBackend.
StorageResponse
A response from calls like Backend::storage_fetch_values or Backend::storage_fetch_descendant_values.
StreamOf
A stream of some item.

Enums

TransactionStatus
The status of the transaction.

Traits

Backend
This trait exposes the interface that Subxt will use to communicate with a backend. Its goal is to be as minimal as possible.
BlockRefT
A trait that a Backend can implement to know when some block can be unpinned: when this is dropped, there are no remaining references to the block that it’s associated with.

Type Aliases

StreamOfResults
A stream of Result<Item, BackendError>.