CombinedBackendBuilder

Struct CombinedBackendBuilder 

pub struct CombinedBackendBuilder<T: Config> { /* private fields */ }
A builder to configure and build a CombinedBackend.

Implementations

Source

impl<T: Config> CombinedBackendBuilder<T>

pub fn new() -> Self

Create a new CombinedBackendBuilder.

pub fn with_archive_backend(self, backend: ArchiveBackend<T>) -> Self

Use the given ArchiveBackend where applicable.

pub fn with_chainhead_backend(self, backend: ChainHeadBackend<T>) -> Self

Use the given ChainHeadBackend where applicable.

pub fn with_legacy_backend(self, backend: LegacyBackend<T>) -> Self

Use the given LegacyBackend where applicable.

pub fn no_default_backends(self) -> Self

pub async fn build( self, rpc_client: impl Into<RpcClient>, ) -> Result<(CombinedBackend<T>, CombinedBackendDriver<T>), CombinedBackendError>

A low-level API to build the backend and driver which requires polling the driver for the backend to make progress.

This is useful if you want to manage the driver yourself, for example if you want to run it in on a specific runtime.

If you just want to run the driver in the background until completion in on the default runtime, use CombinedBackendBuilder::build_with_background_driver instead.

pub async fn build_with_background_driver( self, client: impl Into<RpcClient>, ) -> Result<CombinedBackend<T>, CombinedBackendError>

An API to build the backend and driver which will run in the background until completion on the default runtime.

  • On non-wasm targets, this will spawn the driver on tokio.
  • On wasm targets, this will spawn the driver on wasm-bindgen-futures.