Module dynamic

Module dynamic 

This module ex-exports various helpers for constructing dynamic payloads/queries/addresses.

Re-exports

pub use crate::transactions::dynamic as transaction;
pub use crate::transactions::dynamic as tx;
pub use crate::constants::dynamic as constant;
pub use crate::storage::dynamic as storage;
pub use crate::runtime_apis::dynamic as runtime_api_call;
pub use crate::view_functions::dynamic as view_function_call;
pub use crate::custom_values::dynamic as custom_value;

Macros

value
Construct a scale_value::Value using syntax similar to the serde_jaon::json! macro.

Structs

Value
Value holds a representation of some value that has been decoded, as well as some arbitrary context.

Traits

At
This trait allows indexing into Values (and options of Values) using the At::at() function. It’s a little like Rust’s core::ops::Index trait, but adapted so that we can return and work with optionals.