Module error

Module error 

Types representing the errors that can be returned.

Structs

DecodeError
An error produced while attempting to decode some type.
EncodeError
An error produced while attempting to encode some type.
ExtrinsicDecodeErrorAt
Hex
Display hex strings.
Metadata
Node metadata. This can be constructed by providing some compatible frame_metadata which is then decoded into this. We aim to preserve all of the existing information in the incoming metadata while optimizing the format a little for Subxt’s use cases.
ModuleError
Details about a module error that has occurred.
ModuleErrorDecodeError
Error decoding the ModuleError

Enums

AccountNonceError
ArithmeticError
An error relating to arithmetic when dispatching a transaction.
BackendError
BlockError
BlocksError
Errors constructing streams of blocks.
CombinedBackendError
ConstantError
Something went wrong working with a constant.
CustomValueError
DispatchError
An error dispatching a transaction.
DispatchErrorDecodeError
Error decoding the DispatchError
Error
A global error type. Any of the errors exposed here can convert into this error via .into(), but this error isn’t itself exposed from anything.
EventsError
Error working with events.
ExtrinsicDecodeErrorAtReason
ExtrinsicError
Error working with extrinsics.
LightClientError
Things that can go wrong when constructing the LightClient.
MetadataTryFromError
An error emitted if something goes wrong converting frame_metadata types into crate::Metadata.
ModuleErrorDetailsError
Error decoding the DispatchError
OfflineClientAtBlockError
Errors constructing an offline client at a specific block number.
OnlineClientAtBlockError
Errors constructing an online client at a specific block number.
OnlineClientError
RpcError
An RPC error. Since we are generic over the RPC client that is used, the error is boxed and could be casted.
RuntimeApiError
Error working with Runtime APIs
StorageError
Error working with storage.
StorageKeyError
StorageValueError
TokenError
An error relating to tokens when dispatching a transaction.
TransactionEventsError
Error fetching events for a just-submitted transaction
TransactionExtensionError
An error that can be emitted when trying to construct a crate::config::TransactionExtension, encode data from the instance, or match on signed extensions.
TransactionFinalizedSuccessError
Error waiting for the transaction to be finalized and successful.
TransactionProgressError
Error during the transaction progress.
TransactionStatusError
An error emitted as the result of a transaction progress update.
TransactionalError
An error relating to the transactional layers when dispatching a transaction.
ViewFunctionError
Error working with View Functions.