Metadata

Struct Metadata 

pub struct Metadata { /* private fields */ }
Node metadata. This can be constructed by providing some compatible frame_metadata which is then decoded into this. We aim to preserve all of the existing information in the incoming metadata while optimizing the format a little for Subxt’s use cases.

Implementations

Source

impl Metadata

pub fn arc(self) -> Arc<Metadata>

Metadata tends to be passed around wrapped in an Arc so that it can be cheaply cloned. This is a shorthand to return that.

pub fn decode_from(bytes: &[u8]) -> Result<Metadata, Error>

This is similar to<Metadata as codec::Decode>::decode(&mut bytes), except it is able to attempt to decode from several types.

pub fn from_v16(metadata: RuntimeMetadataV16) -> Result<Metadata, TryFromError>

Convert V16 metadata into Metadata.

pub fn from_v15(metadata: RuntimeMetadataV15) -> Result<Metadata, TryFromError>

Convert V15 metadata into Metadata.

pub fn from_v14(metadata: RuntimeMetadataV14) -> Result<Metadata, TryFromError>

Convert V14 metadata into Metadata.

pub fn from_v13( metadata: &RuntimeMetadataV13, types: &TypeRegistrySet<'_>, ) -> Result<Metadata, Error>

Convert V13 metadata into Metadata, given the necessary extra type information.

pub fn from_v12( metadata: &RuntimeMetadataV12, types: &TypeRegistrySet<'_>, ) -> Result<Metadata, Error>

Convert V12 metadata into Metadata, given the necessary extra type information.

pub fn from_v11( metadata: &RuntimeMetadataV11, types: &TypeRegistrySet<'_>, ) -> Result<Metadata, Error>

Convert V13 metadata into Metadata, given the necessary extra type information.

pub fn from_v10( metadata: &RuntimeMetadataV10, types: &TypeRegistrySet<'_>, ) -> Result<Metadata, Error>

Convert V13 metadata into Metadata, given the necessary extra type information.

pub fn from_v9( metadata: &RuntimeMetadataV9, types: &TypeRegistrySet<'_>, ) -> Result<Metadata, Error>

Convert V9 metadata into Metadata, given the necessary extra type information.

pub fn from_v8( metadata: &RuntimeMetadataV8, types: &TypeRegistrySet<'_>, ) -> Result<Metadata, Error>

Convert V8 metadata into Metadata, given the necessary extra type information.

pub fn types(&self) -> &PortableRegistry

Access the underlying type registry.

pub fn types_mut(&mut self) -> &mut PortableRegistry

Mutable access to the underlying type registry.

pub fn dispatch_error_ty(&self) -> Option<u32>

The type ID of the DispatchError type, if it exists.

pub fn extrinsic(&self) -> &ExtrinsicMetadata

Return details about the extrinsic format.

pub fn outer_enums(&self) -> OuterEnumsMetadata

Return details about the outer enums.

pub fn pallets(&self) -> impl ExactSizeIterator

An iterator over all of the available pallets.

pub fn pallet_by_call_index( &self, variant_index: u8, ) -> Option<PalletMetadata<'_>>

Access a pallet given some call/extrinsic pallet index byte

pub fn pallet_by_event_index( &self, variant_index: u8, ) -> Option<PalletMetadata<'_>>

Access a pallet given some event pallet index byte

pub fn pallet_by_error_index( &self, variant_index: u8, ) -> Option<PalletMetadata<'_>>

Access a pallet given some error pallet index byte

pub fn pallet_by_name(&self, pallet_name: &str) -> Option<PalletMetadata<'_>>

Access a pallet given its name.

pub fn runtime_api_traits(&self) -> impl ExactSizeIterator

An iterator over all of the runtime APIs.

pub fn runtime_api_trait_by_name( &self, name: &str, ) -> Option<RuntimeApiMetadata<'_>>

Access a runtime API trait given its name.

pub fn custom(&self) -> CustomMetadata<'_>

Returns custom user defined types

pub fn hasher(&self) -> MetadataHasher<'_>

Obtain a unique hash representing this metadata or specific parts of it.

pub fn type_hash(&self, id: u32) -> Option<[u8; 32]>

Get type hash for a type in the registry