pub struct WrapperKeepOpaque<T> { /* private fields */ }Expand description
A wrapper for any type T which implement encode/decode in a way compatible with Vec<u8>.
WrapperKeepOpaque stores the type only in its opaque format, aka as a Vec<u8>. To
access the real type T Self::try_decode needs to be used.
Implementations
Sourceimpl<T> WrapperKeepOpaque<T>
impl<T> WrapperKeepOpaque<T>
Sourcepub fn try_decode(&self) -> Option<T>where
T: Decode,
pub fn try_decode(&self) -> Option<T>where
T: Decode,
Try to decode the wrapped type from the inner data.
Returns None if the decoding failed.
Sourcepub fn encoded_len(&self) -> usize
pub fn encoded_len(&self) -> usize
Returns the length of the encoded T.
Sourcepub fn from_encoded(data: Vec<u8>) -> Self
pub fn from_encoded(data: Vec<u8>) -> Self
Create from the given encoded data.
Sourcepub fn from_value(value: T) -> Selfwhere
T: Encode,
pub fn from_value(value: T) -> Selfwhere
T: Encode,
Create from some raw value by encoding it.