This module exposes a backend trait for Subxt which allows us to get and set the necessary information (probably from a JSON-RPC API, but that’s up to the implementation).
Modules
- utils
- Backend utils.
Structs
- Archive
Backend - The archive backend.
- Block
Ref - An opaque struct which, while alive, indicates that some references to a block still exist. This gives the backend the opportunity to keep the corresponding block details around for a while if it likes and is able to. No guarantees can be made about how long the corresponding details might be available for, but if no references to a block exist, then the backend is free to discard any details for it.
- Chain
Head Backend - The chainHead backend.
- Chain
Head Backend Builder - Configure and build an
ChainHeadBackend. - Chain
Head Backend Driver - Driver for the
ChainHeadBackend. This must be polled in order for the backend to make progress. - Combined
Backend - A combined backend. This selects which RPC calls to use based on the
rpc_methodsavailable from the given RPC client we’re given. - Combined
Backend Builder - A builder to configure and build a
CombinedBackend. - Combined
Backend Driver - Driver for the
CombinedBackend. This needs to be polled to ensure that theCombinedBackendcan make progress. It does not need polling ifCombinedBackendDriver::needs_pollingreturnsfalse. - Legacy
Backend - The legacy backend.
- Legacy
Backend Builder - Configure and build an
LegacyBackend. - Storage
Response - A response from calls like
Backend::storage_fetch_valuesorBackend::storage_fetch_descendant_values. - Stream
Of - A stream of some item.
Enums
- Transaction
Status - The status of the transaction.
Traits
- Backend
- This trait exposes the interface that Subxt will use to communicate with a backend. Its goal is to be as minimal as possible.
- Block
RefT - A trait that a
Backendcan implement to know when some block can be unpinned: when this is dropped, there are no remaining references to the block that it’s associated with.
Type Aliases
- Stream
OfResults - A stream of
Result<Item, BackendError>.