pub struct CombinedBackendBuilder<T: Config> { /* private fields */ }Expand description
A builder to configure and build a CombinedBackend.
Implementations
Sourceimpl<T: Config> CombinedBackendBuilder<T>
impl<T: Config> CombinedBackendBuilder<T>
Sourcepub fn new() -> Self
pub fn new() -> Self
Create a new CombinedBackendBuilder.
Sourcepub fn with_archive_backend(self, backend: ArchiveBackend<T>) -> Self
pub fn with_archive_backend(self, backend: ArchiveBackend<T>) -> Self
Use the given ArchiveBackend where applicable.
Sourcepub fn with_chainhead_backend(self, backend: ChainHeadBackend<T>) -> Self
pub fn with_chainhead_backend(self, backend: ChainHeadBackend<T>) -> Self
Use the given ChainHeadBackend where applicable.
Sourcepub fn with_legacy_backend(self, backend: LegacyBackend<T>) -> Self
pub fn with_legacy_backend(self, backend: LegacyBackend<T>) -> Self
Use the given LegacyBackend where applicable.
Sourcepub fn no_default_backends(self) -> Self
pub fn no_default_backends(self) -> Self
Don’t use any default backends; only use what is explicitly configured via
CombinedBackendBuilder::with_archive_backend,
CombinedBackendBuilder::with_chainhead_backend and
CombinedBackendBuilder::with_legacy_backend.
Sourcepub async fn build(
self,
rpc_client: impl Into<RpcClient>,
) -> Result<(CombinedBackend<T>, CombinedBackendDriver<T>), CombinedBackendError>
pub async fn build( self, rpc_client: impl Into<RpcClient>, ) -> Result<(CombinedBackend<T>, CombinedBackendDriver<T>), CombinedBackendError>
A low-level API to build the backend and driver which requires polling the driver for the backend to make progress.
This is useful if you want to manage the driver yourself, for example if you want to run it in on a specific runtime.
If you just want to run the driver in the background until completion in on the default runtime,
use CombinedBackendBuilder::build_with_background_driver instead.
Sourcepub async fn build_with_background_driver(
self,
client: impl Into<RpcClient>,
) -> Result<CombinedBackend<T>, CombinedBackendError>
pub async fn build_with_background_driver( self, client: impl Into<RpcClient>, ) -> Result<CombinedBackend<T>, CombinedBackendError>
An API to build the backend and driver which will run in the background until completion on the default runtime.
- On non-wasm targets, this will spawn the driver on
tokio. - On wasm targets, this will spawn the driver on
wasm-bindgen-futures.