Types representing the errors that can be returned.
Structs
- Decode
Error - An error produced while attempting to decode some type.
- Encode
Error - An error produced while attempting to encode some type.
- Extrinsic
Decode Error At - Hex
- Display hex strings.
- Metadata
- Node metadata. This can be constructed by providing some compatible
frame_metadatawhich is then decoded into this. We aim to preserve all of the existing information in the incoming metadata while optimizing the format a little for Subxt’s use cases. - Module
Error - Details about a module error that has occurred.
- Module
Error Decode Error - Error decoding the
ModuleError
Enums
- Account
Nonce Error - Arithmetic
Error - An error relating to arithmetic when dispatching a transaction.
- Backend
Error - Block
Error - Blocks
Error - Errors constructing streams of blocks.
- Combined
Backend Error - Constant
Error - Something went wrong working with a constant.
- Custom
Value Error - Dispatch
Error - An error dispatching a transaction.
- Dispatch
Error Decode Error - Error decoding the
DispatchError - Error
- A global error type. Any of the errors exposed here can convert into this
error via
.into(), but this error isn’t itself exposed from anything. - Events
Error - Error working with events.
- Extrinsic
Decode Error AtReason - Extrinsic
Error - Error working with extrinsics.
- Light
Client Error - Things that can go wrong when constructing the
LightClient. - Metadata
TryFrom Error - An error emitted if something goes wrong converting
frame_metadatatypes intocrate::Metadata. - Module
Error Details Error - Error decoding the
DispatchError - Offline
Client AtBlock Error - Errors constructing an offline client at a specific block number.
- Online
Client AtBlock Error - Errors constructing an online client at a specific block number.
- Online
Client Error - RpcError
- An RPC error. Since we are generic over the RPC client that is used, the error is boxed and could be casted.
- Runtime
ApiError - Error working with Runtime APIs
- Storage
Error - Error working with storage.
- Storage
KeyError - Storage
Value Error - Token
Error - An error relating to tokens when dispatching a transaction.
- Transaction
Events Error - Error fetching events for a just-submitted transaction
- Transaction
Extension Error - An error that can be emitted when trying to construct a
crate::config::TransactionExtension, encode data from the instance, or match on signed extensions. - Transaction
Finalized Success Error - Error waiting for the transaction to be finalized and successful.
- Transaction
Progress Error - Error during the transaction progress.
- Transaction
Status Error - An error emitted as the result of a transaction progress update.
- Transactional
Error - An error relating to the transactional layers when dispatching a transaction.
- View
Function Error - Error working with View Functions.